@@ -1363,3 +1363,240 @@ class modules_manage_pub(msg):
     def __init__(self):
         super().__init__()
         self.msg = []  # 消息体
+
+#服务器控制机器人进行音频录制
+class audio_input_record(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "task_id": 10000, //任务唯一表示符
+        "msg":
+            {
+                "name": "test_1", //录制音频名称
+                "time": 4 //录制音频时间（单位s）
+            }
+
+    }
+    """
+    topic = "/audio/input/record"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.name = ""  # int型
+            self.time = ""  # string型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        self.task_id = ""  # int型
+        
+#服务器控制机器人进行音频录制返回
+class aduio_input_record_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1 //0:失败,1:成功
+        }
+    }
+    """
+    topic = "/audio/input/record_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+#服务器控制机器人进行巡检点声音采集并分析
+class audio_analysis_check_voice(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "task_id": "10000",
+        "msg":
+            {
+                "index": 10, //对比允许频率强度索引
+                "description": "test_1", //采样点说明
+                "time": 4, //录制音频时间（单位s）
+                "get_method": 1, //频率强度获取方法 现仅有1
+                "analysis_method": 1, // 异常分析方法 现仅有1
+                "save": 1 //采样音频是否保留 0:不保留 1:保留 文件名为<description>_<task_id>.wav
+                "image": 1 //是否需要上传图片 0:不需要 1:上传采样点频谱图 2:上传采样点及索引点频谱图
+            }
+
+    }
+    """
+    topic = "/audio/analysis/check_voice"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.index = ""  # int型
+            self.description = ""  # string型
+            self.time = ""  # int型
+            self.get_method = ""  # int型
+            self.analysis_method = ""  # int型
+            self.save = ""  # int型
+            self.image = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        self.task_id = ""  # int型
+
+#服务器控制机器人进行巡检点声音采集并分析返回
+class audio_analysis_check_voice_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1 //0:失败,1:成功
+        }
+    }
+    """
+    topic = "/audio/analysis/check_voice_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+#设置导航目标点
+class set_targetpoint(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "x":"1.0",//单位m
+            "y":"2.5",//单位m
+            "z":"0",//2D平面导航永远为0
+            "theta":"1.57",//单位弧度
+        }
+
+    }
+    """
+    topic = "/set_targetpoint"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.x = ""
+            self.y = ""
+            self.z = ""
+            self.theta = ""
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+class set_targetpoint_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1 //0:失败,1:成功
+        }
+    }
+    """
+    topic = "/set_targetpoint_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+#视频识别获取数据
+class get_data(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "iType":0, //识别类型 0 digital 1 pointer 2 power
+            "camera_id":"", //相机id
+            "task_type":1 , //任务类型
+            "task_id":10000, // 任务id
+            
+        }
+    }
+    """
+    topic = "/get_data"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.iType = ""  # int型
+            self.camera_id = ""  # string型
+            self.task_type = ""  # int型
+            self.task_id = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+class get_data_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "iType":0, //识别类型 0 digital 1 pointer 2 power
+            "srcframe":"", 
+            "outframe":'' , 
+            "outmessage":'', 
+            "task_type":'',
+            "task_id":'',
+            "timestamp":"",
+            "camera_id":"",
+            "bFlag":"",
+            "sMessage":"",
+            "sType":"",
+            "sImgname":""
+            
+        }
+    }
+    """
+    topic = "/get_data_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.iType = ""  # int型
+            self.camera_id = ""  # string型
+            self.task_type = ""  # int型
+            self.task_id = ""  # int型
+            self.srcframe = ""
+            self.outframe = ""
+            self.outmessage = ""
+            self.timestamp = ""
+            self.bFlag = ""
+            self.sMessage = ""
+            self.sType = ""
+            self.sImgname = ""
+            
+    def __init__(self):
+        super().__init__()
+        self.data = self.msg_class()  # 消息体
\ No newline at end of file
